class Location:
    def __init__(
        self,
        address_locality: str,
        address_region: str,
        address_country: str,
    ):
        self.address_locality = address_locality
        self.address_region = address_region
        self.address_country = address_country
